--- old/usr/src/head/glob.h	Wed Nov  7 16:47:35 2012
+++ new/usr/src/head/glob.h	Wed Nov  7 16:47:35 2012
@@ -19,9 +19,45 @@
  *
  * CDDL HEADER END
  */
+
 /*
+ * Copyright (c) 1989, 1993
+ *	The Regents of the University of California.  All rights reserved.
+ *
+ * This code is derived from software contributed to Berkeley by
+ * Guido van Rossum.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ * 3. Neither the name of the University nor the names of its contributors
+ *    may be used to endorse or promote products derived from this software
+ *    without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
+ * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
+ * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
+ * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
+ * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+ * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+ * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
+ * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+ * SUCH DAMAGE.
+ *
+ *	@(#)glob.h	8.1 (Berkeley) 6/2/93
+ */
+
+/*
  * Copyright 2003 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
+ * Copyright (c) 2012 Gary Mills
  */
 
 /*
@@ -31,26 +67,41 @@
 #ifndef	_GLOB_H
 #define	_GLOB_H
 
-#pragma ident	"%Z%%M%	%I%	%E% SMI"
-
 #include <sys/feature_tests.h>
 #include <sys/types.h>
+#include <sys/stat.h>
+#include <dirent.h>
 
 #ifdef	__cplusplus
 extern "C" {
 #endif
 
+struct stat;
+
 typedef	struct	glob_t	{
-	size_t	gl_pathc;		/* Count of paths matched by pattern */
-	char	**gl_pathv;		/* List of matched pathnames */
-	size_t	gl_offs;		/* # of slots reserved in gl_pathv */
-	/* following are internal to the implementation */
-	char	**gl_pathp;		/* gl_pathv + gl_offs */
-	int	gl_pathn;		/* # of elements allocated */
+	/* Members required by POSIX */
+	size_t	gl_pathc;	/* Total count of paths matched by pattern */
+	char	**gl_pathv;	/* List of matched pathnames */
+	size_t	gl_offs;	/* # of slots reserved in gl_pathv */
+	/* Non-POSIX extensions, from Openbsd */
+	int gl_matchc;		/* Count of paths matching pattern. */
+	int gl_flags;		/* Copy of flags parameter to glob. */
+	/* Members only accessed when Non-POSIX flags are specified. */
+	struct stat **gl_statv;	/* Stat entries corresponding to gl_pathv */
+	/*
+	 * Alternate filesystem access methods for glob; replacement
+	 * versions of closedir(3), readdir(3), opendir(3), stat(2)
+	 * and lstat(2).
+	 */
+	void (*gl_closedir)(void *);
+	struct dirent *(*gl_readdir)(void *);
+	void *(*gl_opendir)(const char *);
+	int (*gl_lstat)(const char *, struct stat *);
+	int (*gl_stat)(const char *, struct stat *);
 }	glob_t;
 
 /*
- * "flags" argument to glob function.
+ * POSIX "flags" argument to glob function.
  */
 #define	GLOB_ERR	0x0001		/* Don't continue on directory error */
 #define	GLOB_MARK	0x0002		/* Mark directories with trailing / */
@@ -61,6 +112,18 @@
 #define	GLOB_NOESCAPE	0x0040		/* Backslashes do not quote M-chars */
 
 /*
+ * Non-POSIX "flags" argument to glob function, from Openbsd.
+ */
+#define	GLOB_BRACE	0x0080	/* Expand braces ala csh. */
+#define	GLOB_MAGCHAR	0x0100	/* Pattern had globbing characters. */
+#define	GLOB_NOMAGIC	0x0200	/* GLOB_NOCHECK without magic chars (csh). */
+#define	GLOB_QUOTE	0x0400	/* Quote special chars with \. */
+#define	GLOB_TILDE	0x0800	/* Expand tilde names from the passwd file. */
+#define	GLOB_LIMIT	0x2000	/* Limit pattern match output to ARG_MAX */
+#define	GLOB_KEEPSTAT	0x4000	/* Retain stat data for paths in gl_statv. */
+#define	GLOB_ALTDIRFUNC	0x8000	/* Use alternately specified directory funcs. */
+
+/*
  * Error returns from "glob"
  */
 #define	GLOB_NOSYS	(-4)		/* function not supported (XPG4) */
@@ -67,6 +130,7 @@
 #define	GLOB_NOMATCH	(-3)		/* Pattern does not match */
 #define	GLOB_NOSPACE	(-2)		/* Not enough memory */
 #define	GLOB_ABORTED	(-1)		/* GLOB_ERR set or errfunc return!=0 */
+#define	GLOB_ABEND	GLOB_ABORTED	/* backward compatibility */
 
 #if defined(__STDC__)
 extern int glob(const char *_RESTRICT_KYWD, int, int(*)(const char *, int),
